@@ -1,3 +1,3 @@
 from .main import tokenize
 from .main import rel_freq
-from .main import tfidf
\ No newline at end of file
+from .main import tf_idf
\ No newline at end of file
